==> linkify-1.0.0.tar.gz: test/linkify_test.dart <==
import 'package:collection/collection.dart';
import 'package:linkify/linkify.dart';
import 'package:test/test.dart';

final listEqual = const ListEquality().equals;

void expectListEqual(List actual, List expected) {
  expect(
    listEqual(
      actual,
      expected,
    ),
    true,
    reason: "Expected $actual to be $expected",
  );
}

void main() {
  test('Parses only text', () {
    expectListEqual(
      linkify("Lorem ipsum dolor sit amet"),
      [TextElement("Lorem ipsum dolor sit amet")],
    );
  });

  test('Parses only text with multiple lines', () {
    expectListEqual(
      linkify("Lorem ipsum\ndolor sit amet"),
      [TextElement("Lorem ipsum\ndolor sit amet")],
    );
  });

  test('Parses only link', () {
    expectListEqual(
      linkify("https://example.com"),
      [LinkElement("https://example.com")],
    );
  });

  test('Parses only links with space', () {
    expectListEqual(
      linkify("https://example.com https://google.com"),
      [
        LinkElement("https://example.com"),
        TextElement(" "),
        LinkElement("https://google.com"),
      ],
    );
  });

  test('Parses links with text', () {
    expectListEqual(
      linkify(
        "Lorem ipsum dolor sit amet https://example.com https://google.com",
      ),
      [
        TextElement("Lorem ipsum dolor sit amet "),
        LinkElement("https://example.com"),
        TextElement(" "),
        LinkElement("https://google.com"),
      ],
    );
  });

  test('Parses links with text with newlines', () {
    expectListEqual(
      linkify(
        "https://google.com\nLorem ipsum\ndolor sit amet\nhttps://example.com",
      ),
      [
        LinkElement("https://google.com"),
        TextElement("\nLorem ipsum\ndolor sit amet\n"),
        LinkElement("https://example.com"),
      ],
    );
  });

  test('Parses email', () {
    expectListEqual(
      linkify("person@example.com"),
      [EmailElement("person@example.com")],
    );
  });
}

==> linkify-2.0.2.tar.gz: test/linkify_test.dart <==
import 'package:collection/collection.dart';
import 'package:linkify/linkify.dart';
import 'package:test/test.dart';

final listEqual = const ListEquality().equals;

void expectListEqual(List actual, List expected) {
  expect(
    listEqual(
      actual,
      expected,
    ),
    true,
    reason: "Expected $actual to be $expected",
  );
}

void main() {
  test('Parses only text', () {
    expectListEqual(
      linkify("Lorem ipsum dolor sit amet"),
      [TextElement("Lorem ipsum dolor sit amet")],
    );
  });

  test('Parses only text with multiple lines', () {
    expectListEqual(
      linkify("Lorem ipsum\ndolor sit amet"),
      [TextElement("Lorem ipsum\ndolor sit amet")],
    );
  });

  test('Parses only link', () {
    expectListEqual(
      linkify("https://example.com"),
      [UrlElement("https://example.com", "example.com")],
    );
  });

  test('Parses only link with no humanize', () {
    expectListEqual(
      linkify("https://example.com", options: LinkifyOptions(humanize: false)),
      [UrlElement("https://example.com")],
    );
  });

  test('Parses only links with space', () {
    expectListEqual(
      linkify("https://example.com https://google.com"),
      [
        UrlElement("https://example.com", "example.com"),
        TextElement(" "),
        UrlElement("https://google.com", "google.com"),
      ],
    );
  });

  test('Parses links with text', () {
    expectListEqual(
      linkify(
        "Lorem ipsum dolor sit amet https://example.com https://google.com",
      ),
      [
        TextElement("Lorem ipsum dolor sit amet "),
        UrlElement("https://example.com", "example.com"),
        TextElement(" "),
        UrlElement("https://google.com", "google.com"),
      ],
    );
  });

  test('Parses links with text with no humanize', () {
    expectListEqual(
      linkify(
        "Lorem ipsum dolor sit amet https://example.com https://google.com",
        options: LinkifyOptions(humanize: false),
      ),
      [
        TextElement("Lorem ipsum dolor sit amet "),
        UrlElement("https://example.com"),
        TextElement(" "),
        UrlElement("https://google.com"),
      ],
    );
  });

  test('Parses links with text with newlines', () {
    expectListEqual(
      linkify(
        "https://google.com\nLorem ipsum\ndolor sit amet\nhttps://example.com",
      ),
      [
        UrlElement("https://google.com", "google.com"),
        TextElement("\nLorem ipsum\ndolor sit amet\n"),
        UrlElement("https://example.com", "example.com"),
      ],
    );
  });

  test('Parses email', () {
    expectListEqual(
      linkify("person@example.com"),
      [EmailElement("person@example.com")],
    );
  });

  test('Parses email and link', () {
    expectListEqual(
      linkify("person@example.com at https://google.com"),
      [
        EmailElement("person@example.com"),
        TextElement(" at "),
        UrlElement("https://google.com", "google.com")
      ],
    );
  });

  test("Doesn't parses email and link with no linkifiers", () {
    expectListEqual(
      linkify("person@example.com at https://google.com", linkifiers: []),
      [
        TextElement("person@example.com at https://google.com"),
      ],
    );
  });
}
